@@ -1,5 +1,7 @@
 from uploader_client.interfaces.base import (
     AbstractInterface,
+    AbstractRequest,
+    AbstractResult,
 )
 from uploader_client.interfaces.rest import (
     OpenAPIInterface,
@@ -10,6 +12,8 @@ from uploader_client.interfaces.rest import (
 
 __all__ = [
     'AbstractInterface',
+    'AbstractRequest',
+    'AbstractResult',
     'OpenAPIRequest',
     'OpenAPIInterface',
     'Result',
