@@ -56,10 +56,10 @@ class Entry:
             )
         )
 
-
 class AbstractLogger(ABC):
+    """Абстрактный логгер."""
 
     @abstractmethod
-    def log(self, entry) -> None:
+    async def log(self, entry) -> None:
         """Логирует сообщение об ошибке."""
         raise NotImplementedError()
